@@ -13,7 +13,7 @@ use vars qw($VERSION $DEBUG @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 require Exporter;
 
 @ISA = qw(Exporter);
-@EXPORT= qw( send_cm11 receive_cm11 read_cm11 dim_decode_cm11 );
+@EXPORT= qw();
 @EXPORT_OK= qw();
 %EXPORT_TAGS = (FUNC    => [qw( send_cm11   receive_cm11
                                 read_cm11   dim_decode_cm11 )]);
@@ -24,7 +24,7 @@ $EXPORT_TAGS{ALL} = \@EXPORT_OK;
 
 #### Package variable declarations ####
 
-($VERSION) = q$Revision: 2.09 $ =~ /: (\S+)/; # Note: cvs version reset when we moved to sourceforge
+$VERSION = '2.06';
 $DEBUG = 0;
 my $Last_Dcode;
 
@@ -75,14 +75,14 @@ my %table_hcodes2 = qw(0110 A  1110 B  0010 C  1010 D  0001 E  1001 F  0101 G  1
 my %table_dcodes2 = qw(0110 1  1110 2  0010 3  1010 4  0001 5  1001 6  0101 7  1101 8
                        0111 9  1111 A  0011 B  1011 C  0000 D  1000 E  0100 F  1100 G);
 my %table_fcodes2 = qw(0010 J  0011 K  0100 L  0101 M  0001 O  0000 P 
-                       0111 Z 1010 PRESET_DIM1 1011 PRESET_DIM2
+                       1010 PRESET_DIM1 1011 PRESET_DIM2
                        1101 STATUS_ON   1110 STATUS_OFF 1111 STATUS);
 
 
 sub receive_buffer {
     my ($serial_port) = @_;
 
-    if (exists $main::config_parms{debug}) {
+    if (defined $main::config_parms{debug}) {
         $DEBUG = ($main::config_parms{debug} eq 'X10') ? 1 : 0;
     }
 
@@ -109,40 +109,27 @@ sub receive_buffer {
     my $data_h = unpack('H*',  $data);
     print "receive buffer length=$length, mask=$mask, data_h=$data_h.\n" if $DEBUG;
 
-    my ($house, $function, $device, $i, $extended_count);
-
+    my ($house, $function, $device, $i);
     undef $data;
     foreach my $byte (@bytes) {
-              # Send extended data into MH as untranslated hex.           
-        if ($extended_count) {
-           $data .= unpack('H*', $byte);
-           --$extended_count;
-           ++$i;
+        my $bits = unpack('B8', $byte);
+        my $house_bits = substr($bits, 0, 4);
+        my $code_bits  = substr($bits, 4, 4);
+        print "CM11 error, not a valid house code: $house_bits\n" unless $house = $table_hcodes2{$house_bits};
+        if (substr($mask, -(++$i), 1)) {
+            print "CM11 error, not a valid function code: $code_bits\n" unless $function = $table_fcodes2{$code_bits};
+#       print "function=$house$function\n";
+
+                                # Add device code back in, since this is not included in status :(
+            $function = $Last_Dcode . $function if $function =~ /^STATUS/;
+
+            $data .= $house . $function;
+            print "CM11 db: data=$data\n" if $DEBUG;
         }
         else {
-           my $bits = unpack('B8', $byte);
-           my $house_bits = substr($bits, 0, 4);
-           my $code_bits  = substr($bits, 4, 4);
-           print "CM11 error, not a valid house code: $house_bits\n" unless $house = $table_hcodes2{$house_bits};
-           if (substr($mask, -(++$i), 1)) {
-               print "CM11 error, not a valid function code: $code_bits at byte $i value $bits\n" unless $function = $table_fcodes2{$code_bits};
-#          print "function=$house$function\n";
-
-                                   # Add device code back in, since this is not included in status :(
-               $function = $Last_Dcode . $function if $function =~ /^STATUS/;
-                                   # Handle Vehicle Interface RF Receiver extended code - assume length of 3 for extended
-               $extended_count = 3 if ($function eq 'Z');
-## 2.08, but 'Z' not numeric ##
-##               $extended_count = 3 if ($function == 'Z');
-
-               $data .= $house . $function;
-                 print "CM11 db: data=$data\n" if $DEBUG;
-           }
-           else {
-               print "CM11 error, not a valid device code: $code_bits\n" unless $device = $table_dcodes2{$code_bits};
-#          print "device=$house$device\n";
-               $data .= $house . $device;
-           }
+            print "CM11 error, not a valid device code: $code_bits\n" unless $device = $table_dcodes2{$code_bits};
+#       print "device=$house$device\n";
+            $data .= $house . $device;
         }
 #       print "byte=$byte, $bits\n";
     }
@@ -204,11 +191,9 @@ sub format_data {
         my $b4c = unpack('C', $b4);
         my $b5c = unpack('C', $b5);
         $extended_checksum = $b3c + $b4c + $b5c;
-	if ($DEBUG) {
-            printf "CM11 ed=%d, b345=0x%0.2x,0x%0.2x,0x%0.2x ex=%s cs=0x%0.2x\n",
-	    $extended_data, $b3c, $b4c, $b5c, $extended_string,
-	    $extended_checksum;
-	}
+        printf ("CM11 ed=%d, b345=0x%0.2x,0x%0.2x,0x%0.2x ex=%s cs=0x%0.2x\n",
+	        $extended_data, $b3c, $b4c, $b5c, $extended_string,
+	        $extended_checksum) if $DEBUG;
     }
                                 # Test for device code
     elsif ($code_bits = $table_dcodes{$code}) {
@@ -270,7 +255,7 @@ sub format_data {
 sub send {
     my ($serial_port, $house_code) = @_;
 
-    if (exists $main::config_parms{debug}) {
+    if (defined $main::config_parms{debug}) {
         $DEBUG = ($main::config_parms{debug} eq 'X10') ? 1 : 0;
 #       &Win32::SerialPort::debug(1) if $DEBUG;
     }
@@ -283,11 +268,7 @@ sub send {
     print "CM11 send: ", unpack('H*', $data_snd), "\n" if $DEBUG;
 
     print "Bad cm11 data send transmition\n" unless length($data_snd) == $serial_port->write($data_snd);
-
-                                # Note: Skip the power fail check, because we the
-                                # checksum might be the power fail flag (0xa5)
-    my $data_rcv = &read($serial_port, 0, 1); 
-
+    my $data_rcv = &read($serial_port);
     my $data_d = unpack('C', $data_rcv);
 
                                 # Unrelated incoming data ... process and re-start
@@ -308,7 +289,7 @@ sub send {
     print "Bad cm11 acknowledge send transmition\n" unless 1 == $serial_port->write($pc_ok);
 
     $data_rcv = &read($serial_port);
-    $data_d = unpack('C', $data_rcv);
+    my $data_d = unpack('C', $data_rcv);
 
     if ($data_d == 0x55) {
         print "CM11 done\n" if $DEBUG;
@@ -320,7 +301,7 @@ sub send {
         goto RETRY if $retry_cnt++ < 3;
     }
 
-    if (exists $main::config_parms{debug}) {
+    if (defined $main::config_parms{debug}) {
 #       &Win32::SerialPort::debug(0) if $DEBUG;
     }
 
@@ -328,13 +309,13 @@ sub send {
 }
 
 sub read {
-    my ($serial_port, $no_block, $no_power_fail_check) = @_;
+    my ($serial_port, $no_block) = @_;
     my $data;
                                 # Note ... for dim commands > 20, this will time out after 20*40=1 seconds 
                                 # No harm done, but we would rather not wait :)
     my $tries = ($no_block) ? 1 : 20;
 
-    if (exists $main::config_parms{debug}) {
+    if (defined $main::config_parms{debug}) {
         $DEBUG = ($main::config_parms{debug} eq 'X10') ? 1 : 0;
     }
 
@@ -350,7 +331,7 @@ sub read {
 
                                 # If we received the power-fail string (0xa5), reset with a blank macro command
                                 #  - Protocol.txt says to send macros string, but that did not work.
-            if ($data_d == 165 and !$no_power_fail_check) {
+            if ($data_d == 165) {
 
 #55 to 48   timer download header (0x9b)
 #47 to 40   Current time (seconds)
@@ -380,16 +361,11 @@ sub read {
                                        $Wday,
                                        0x03);    # Not sure what is best here.  x10d.c did this.
             
-                print "\nCM11 power fail detected.  Resetting the CM11 clock with:\n $localtime\n";
-                my $results = $serial_port->write($power_reset);
+                print "\nCM11 power fail detected.  Reseting the CM11 clock with:\n $localtime\n $power_reset.\n";
+                print "  results:", $serial_port->write($power_reset), ".\n";
                 select undef, undef, undef, 50 / 1000;
                 my $checksum = $serial_port->input; # Receive, but ignore, checksum
-		if ($DEBUG) {
-                    printf "\npower_reset: %s %s %s %s %s %s %s\n",
-			unpack ('H2H2H2H2H2H2H2', $power_reset);
-                    print "  sent $results bytes\n";
-                    printf "  checksum = %x\n", ord($checksum);
-		}
+                print "  checksum=$checksum.\n";
                 my $pc_ok = pack('C', 0x00);
                 print "Bad cm11 checksum acknowledge\n" unless 1 == $serial_port->write($pc_ok);
 #                undef $data;
@@ -420,7 +396,7 @@ sub dim_level_decode {
                           9 0111 10 1111 11 0011 12 1011 13 0000 14 1000 15 0100 16 1100
                           A 1111  B 0011  C 1011  D 0000  E 1000  F 0100  G 1100);
 
-    if (exists $main::config_parms{debug}) {
+    if (defined $main::config_parms{debug}) {
         $DEBUG = ($main::config_parms{debug} eq 'X10') ? 1 : 0;
     }
 
@@ -545,13 +521,6 @@ For example, the following commands enable preset value 18:
   ControlX10::CM11::send($serial_port,'M4');           # Address thermostat
   ControlX10::CM11::send($serial_port,'OPRESET_DIM2'); # Select preset 18
 
-
-Starting in version 2.07, incoming extended data is also processed.
-The first character will be the I<House Code> in the range [A..P].
-The next character will be I<Z>, indicating extended data.
-The remaining data will be the extended data.
-
-
 =item read
 
 This checks for an incoming transmission. It will return "" for no input.
@@ -619,13 +588,12 @@ may be received from a CM11 and will be properly decoded.
     
 =head1 EXPORTS
 
-The B<send_cm11>, B<receive_cm11>, B<read_cm11>, and B<dim_decode_cm11>
-functions are exported by default starting with Version 2.09.
-They are identical to the "fully-qualified" names and accept the same
-parameters. The I<export on request> tag C<:FUNC> is maintained for
-compatibility (but deprecated).
+Nothing is exported by default. The B<send_cm11>, B<receive_cm11>,
+B<read_cm11>, and B<dim_decode_cm11> functions can be exported on request
+with the tag C<:FUNC>. They are identical to the "fully-qualified" names
+and accept the same parameters.
 
-  use ControlX10::CM11;
+  use ControlX10::CM11 qw( :FUNC 2.06 );
   send_cm11($serial_port, 'A1');            # send() - address
   send_cm11($serial_port, 'AJ');            # send() - function
   $data = receive_cm11($serial_port);           # receive_buffer()
@@ -639,27 +607,14 @@ Bruce Winter  bruce@misterhouse.net  http://misterhouse.net
 CPAN packaging by Bill Birthisel wcbirthisel@alum.mit.edu
 http://members.aol.com/bbirthisel
 
-=head2 MAILING LISTS
-
-General information about the mailing lists is at:
-
-  http://lists.sourceforge.net/mailman/listinfo/misterhouse-users
-  http://lists.sourceforge.net/mailman/listinfo/misterhouse-announce
-
-To post to this list, send your email to:
-
-  misterhouse-users@lists.sourceforge.net
-
-If you ever want to unsubscribe or change your options (eg, switch to
-or from digest mode, change your password, etc.), visit your
-subscription page at:
-
-  http://lists.sourceforge.net/mailman/options/misterhouse-users/$user_id
-
 =head1 SEE ALSO
 
 mh can be download from http://misterhouse.net
 
+You can subscribe to the mailing list at http://www.onelist.com/subscribe.cgi/misterhouse
+
+You can view the mailing list archive at http://www.onelist.com/archives.cgi/misterhouse
+
 Win32::SerialPort and Device::SerialPort from CPAN
 
 CM11A Protocol documentation available at http://www.x10.com
@@ -668,16 +623,9 @@ perl(1).
 
 =head1 COPYRIGHT
 
-Copyright (C) 2000 Bruce Winter. All rights reserved.
+Copyright (C) 1999 Bruce Winter. All rights reserved.
 
 This module is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself. 30 January 2000.
+under the same terms as Perl itself. 20 December 1999.
 
 =cut
-
-#
-# $Log: CM11.pm,v $
-# Revision 2.08  2000/01/29 20:07:01  winter
-# - add $no_power_fail_check.
-#
-#
